.. module:: wwdtm.guest

*****
guest
*****

This module provides objects used to retrieve guests, guest information and
guest details from a copy of the Wait Wait Don't Tell Me! Stats database.

Guest
=====

.. autoclass:: Guest
    :members:
    :inherited-members:

GuestAppearances
================

.. autoclass:: GuestAppearances
    :members:
    :inherited-members:

GuestUtility
============

.. autoclass:: GuestUtility
    :members:
    :inherited-members:
